#include "sub_s.hh"
#include "pub_c.hh"


class Client: public _sk_Subscriber
{
    public:
	Client(const char *name=NULL) : _sk_Subscriber(name) {} 
	~Client() {}

	void receive_update(const Quote& q) {
		cout << "Received update: " << endl;
		cout << q << endl;
	}
};


int main(int argc, char *const *argv)
{
	CORBA::ORB_var orb = CORBA::ORB_init(argc, argv);
	CORBA::BOA_var boa = orb->BOA_init(argc, argv);

	CORBA::BOA::scope(CORBA::BOA::SCOPE_LOCAL); // Create Transient client

	Client client;
	boa->obj_is_ready(&client);

	Publisher_var publisher;

	try {
		publisher = Publisher::_bind();
	}
	catch (const CORBA::Exception& e) {
		cout << "Client: Unable to bind to publisher" << endl;
		cout << e << endl;
		return 1;
	}

	cout << "Successfully bound to publisher" << endl;

	try {
		publisher->add_subscriber(&client);
	}
	catch (const CORBA::Exception& e) {
		cout << "Client: Unable to add subscriber" << endl;
		cout << e << endl;
		return 1;
	}

	boa->impl_is_ready();	// Wait for incoming calls
	return 0;
}
